@@ -44,8 +44,8 @@ The refreshing frequency can be specified via the :paramref:`~ShadersMixin.add_r
 For to disable the automatic creation of a timer event pass a zero value to this argument.
 
 .. hint::
-    The demo apps :ref:`ComPartY <https://gitlab.com/ae-group/comparty>` and
-    :ref:`GlslTester <https://github.com/AndiEcker/glsl_tester>` are disabling the automatic timer event
+    The demo apps `ComPartY <https://gitlab.com/ae-group/comparty>`_ and
+    `GlslTester <https://github.com/AndiEcker/glsl_tester>`_ are disabling the automatic timer event
     for each shader and using instead one app internal timer event for to update all active shaders.
 
 
@@ -69,7 +69,7 @@ The animated :data:`plasma hearts shader <plasma_hearts_shader_code>` is inspire
 https://github.com/kivy/kivy/blob/master/examples/shader/plasma.py.
 
 .. hint::
-    The :ref:`ComPartY <https://gitlab.com/ae-group/comparty>` app is demonstrating the usage of this portion
+    The `ComPartY <https://gitlab.com/ae-group/comparty>`_ app is demonstrating the usage of this portion
     by implementing into its root widget all the built-in shaders of this portion.
 
 The literals of the shader code got converted into constants following the
@@ -86,7 +86,7 @@ from kivy.graphics.vertex_instructions import Rectangle         # type: ignore #
 from ae.base import UNSET, os_platform                          # type: ignore
 
 
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 
 RendererType = Dict[str, Any]       #: used for to store renderer
